# Impira Python SDK

Impira enables you to get everything you need from your PDFs, scanned documents, images, and more — with the help of machine learning. This API allows you to access Impira programatically through Python.

## Installing

You can install the Impira Python SDK directly through pip:

```
$ pip install impira
```

## Examples

The examples directory contains end-to-end working examples for how to use the SDK. `upload_files.py` walks through uploading
a file, either locally or through a URL, and then waiting for its results.
